@@ -26,7 +26,7 @@ from cproton import PN_EOS, PN_OK, PN_SASL_AUTH, PN_SASL_NONE, PN_SASL_OK, PN_SA
     PN_SSL_RESUME_REUSED, PN_SSL_RESUME_UNKNOWN, PN_SSL_SHA1, PN_SSL_SHA256, PN_SSL_SHA512, PN_SSL_VERIFY_PEER, \
     PN_SSL_VERIFY_PEER_NAME, PN_TRACE_DRV, PN_TRACE_FRM, PN_TRACE_OFF, PN_TRACE_RAW, pn_error_text, pn_sasl, \
     pn_sasl_allowed_mechs, pn_sasl_config_name, pn_sasl_config_path, pn_sasl_done, pn_sasl_extended, \
-    pn_sasl_get_allow_insecure_mechs, pn_sasl_get_mech, pn_sasl_get_user, pn_sasl_outcome, \
+    pn_sasl_get_allow_insecure_mechs, pn_sasl_get_mech, pn_sasl_get_user, pn_sasl_get_authorization, pn_sasl_outcome, \
     pn_sasl_set_allow_insecure_mechs, pn_ssl, pn_ssl_domain, pn_ssl_domain_allow_unsecured_client, pn_ssl_domain_free, \
     pn_ssl_domain_set_credentials, pn_ssl_domain_set_peer_authentication, pn_ssl_domain_set_trusted_ca_db, \
     pn_ssl_get_cert_fingerprint, pn_ssl_get_cipher_name, pn_ssl_get_peer_hostname, pn_ssl_get_protocol_name, \
@@ -74,14 +74,12 @@ class Transport(Wrapper):
     TRACE_RAW = PN_TRACE_RAW
     """ Log raw binary data going in and out of the transport. """
 
-
     CLIENT = 1
     """ Transport mode is as a client. """
 
     SERVER = 2
     """ Transport mode is as a server. """
 
-
     @staticmethod
     def wrap(impl):
         if impl is None:
@@ -131,7 +129,7 @@ class Transport(Wrapper):
     def log(self, message):
         """
         Log a message using a transport's logging mechanism.
-        
+
         This can be useful in a debugging context as the log message will
         be prefixed with the transport's identifier.
 
@@ -201,7 +199,7 @@ class Transport(Wrapper):
     def user(self):
         """
         The authenticated user.
- 
+
         On the client it will return whatever user was passed in to the
         :attr:`Connection.user` attribute of the bound connection.
 
@@ -279,7 +277,7 @@ class Transport(Wrapper):
         """
         Get the amount of free space for input following the transport's
         tail pointer.
-        
+
         :return: Available space for input in bytes.
         :rtype: ``int``
         :raise: :exc:`TransportException` if there is any Proton error.
@@ -607,6 +605,31 @@ class SASL(Wrapper):
         """
         return pn_sasl_get_user(self._sasl)
 
+    @property
+    def authorization(self):
+        """
+        Retrieve the requested authorization user. This is usually used at the the
+        server end to find the name of any requested authorization user.
+
+        If the peer has not requested an authorization user or the SASL mechanism has
+        no capability to transport an authorization id this will be the same as the
+        authenticated user.
+
+        Note that it is the role of the server to ensure that the authenticated user is
+        actually allowed to act as the requested authorization user.
+
+        If :meth:`outcome` returns a value other than :const:`OK`, then
+        there will be no user to return. The returned value is only reliable
+        after the ``PN_TRANSPORT_AUTHENTICATED`` event has been received.
+
+        :rtype: * If the SASL layer was not negotiated then ``0`` is returned.
+                * If the ``ANONYMOUS`` mechanism is used then the user will be
+                  ``"anonymous"``.
+                * Otherwise a string containing the user is
+                  returned.
+        """
+        return pn_sasl_get_authorization(self._sasl)
+
     @property
     def mech(self):
         """
@@ -614,7 +637,7 @@ class SASL(Wrapper):
 
         The returned value is only reliable after the ``PN_TRANSPORT_AUTHENTICATED``
         event has been received.
-        
+
         :rtype: The authentication mechanism selected by the SASL layer.
         """
         return pn_sasl_get_mech(self._sasl)
@@ -623,7 +646,7 @@ class SASL(Wrapper):
     def outcome(self):
         """
         Retrieve the outcome of SASL negotiation.
-        
+
         :rtype: * ``None`` if no negotiation has taken place.
                 * Otherwise the outcome of the negotiation.
         """
@@ -734,7 +757,6 @@ class SSLDomain(object):
     ANONYMOUS_PEER = PN_SSL_ANONYMOUS_PEER
     """Do not require a certificate nor cipher authorization."""
 
-
     def __init__(self, mode):
         self._domain = pn_ssl_domain(mode)
         if self._domain is None:
@@ -810,7 +832,8 @@ class SSLDomain(object):
     def set_peer_authentication(self, verify_mode, trusted_CAs=None):
         """
         This method controls how the peer's certificate is validated, if at all.  By default,
-        neither servers nor clients attempt to verify their peers (PN_SSL_ANONYMOUS_PEER).
+        servers do not attempt to verify their peers (PN_SSL_ANONYMOUS_PEER) but
+        clients attempt to verify both the certificate and peer name (PN_SSL_VERIFY_PEER_NAME).
         Once certificates and trusted CAs are configured, peer verification can be enabled.
 
         .. note:: In order to verify a peer, a trusted CA must be configured. See
@@ -824,7 +847,7 @@ class SSLDomain(object):
             previous setting.
 
         :param verify_mode: The level of validation to apply to the peer, one of :const:`VERIFY_PEER`,
-                            :const:`VERIFY_PEER_NAME`, :const:`ANONYMOUS_PEER`, 
+                            :const:`VERIFY_PEER_NAME`, :const:`ANONYMOUS_PEER`,
         :type verify_mode: ``int``
         :param trusted_CAs: Path to a database of trusted CAs that the server will advertise.
         :type trusted_CAs: ``str``
@@ -855,7 +878,7 @@ class SSLDomain(object):
 class SSL(object):
     """
     An SSL session associated with a transport. A transport must have
-    an SSL object in order to "speak" SSL over its connection.   
+    an SSL object in order to "speak" SSL over its connection.
     """
 
     @staticmethod
@@ -973,11 +996,11 @@ class SSL(object):
         usually contains the following values:
 
             * :const:`CERT_COUNTRY_NAME`
-            * :const:`CERT_STATE_OR_PROVINCE` 
+            * :const:`CERT_STATE_OR_PROVINCE`
             * :const:`CERT_CITY_OR_LOCALITY`
             * :const:`CERT_ORGANIZATION_NAME`
             * :const:`CERT_ORGANIZATION_UNIT`
-            * :const:`CERT_COMMON_NAME` 
+            * :const:`CERT_COMMON_NAME`
 
         :param subfield_name: The enumeration representing the required
                               sub field listed above
@@ -1008,7 +1031,7 @@ class SSL(object):
         """
         A convenience method to get a string that contains the :const:`CERT_COMMON_NAME`
         sub field of the subject field in the ssl certificate.
-        
+
         :return: A string containing the :const:`CERT_COMMON_NAME` sub field.
         :rtype: ``str``
         """
@@ -1018,7 +1041,7 @@ class SSL(object):
         """
         A convenience method to get a string that contains the :const:`CERT_ORGANIZATION_NAME`
         sub field of the subject field in the ssl certificate.
-        
+
         :return: A string containing the :const:`CERT_ORGANIZATION_NAME` sub field.
         :rtype: ``str``
         """
@@ -1028,7 +1051,7 @@ class SSL(object):
         """
         A convenience method to get a string that contains the :const:`CERT_ORGANIZATION_UNIT`
         sub field of the subject field in the ssl certificate.
-        
+
         :return: A string containing the :const:`CERT_ORGANIZATION_UNIT` sub field.
         :rtype: ``str``
         """
@@ -1038,7 +1061,7 @@ class SSL(object):
         """
         A convenience method to get a string that contains the :const:`CERT_CITY_OR_LOCALITY`
         sub field of the subject field in the ssl certificate.
-        
+
         :return: A string containing the :const:`CERT_CITY_OR_LOCALITY` sub field.
         :rtype: ``str``
         """
@@ -1048,7 +1071,7 @@ class SSL(object):
         """
         A convenience method to get a string that contains the :const:`CERT_COUNTRY_NAME`
         sub field of the subject field in the ssl certificate.
-        
+
         :return: A string containing the :const:`CERT_COUNTRY_NAME` sub field.
         :rtype: ``str``
         """
@@ -1058,7 +1081,7 @@ class SSL(object):
         """
         A convenience method to get a string that contains the :const:`CERT_STATE_OR_PROVINCE`
         sub field of the subject field in the ssl certificate.
-        
+
         :return: A string containing the :const:`CERT_STATE_OR_PROVINCE` sub field.
         :rtype: ``str``
         """
@@ -1096,7 +1119,7 @@ class SSL(object):
         """
         A convenience method to get the :const:`SHA1` fingerprint of the
         certificate.
-        
+
         :return: Hex fingerprint in a string, or ``None`` if an error occurred.
         :rtype: ``str`` or ``None``
         """
@@ -1106,7 +1129,7 @@ class SSL(object):
         """
         A convenience method to get the :const:`SHA256` fingerprint of the
         certificate.
-        
+
         :return: Hex fingerprint in a string, or ``None`` if an error occurred.
         :rtype: ``str`` or ``None``
         """
@@ -1117,7 +1140,7 @@ class SSL(object):
         """
         A convenience method to get the :const:`SHA512` fingerprint of the
         certificate.
-        
+
         :return: Hex fingerprint in a string, or ``None`` if an error occurred.
         :rtype: ``str`` or ``None``
         """
@@ -1128,7 +1151,7 @@ class SSL(object):
         """
         A convenience method to get the :const:`MD5` fingerprint of the
         certificate.
-        
+
         :return: Hex fingerprint in a string, or ``None`` if an error occurred.
         :rtype: ``str`` or ``None``
         """
@@ -1185,7 +1208,7 @@ class SSL(object):
         Manage the expected name of the remote peer.
 
         The hostname is used for two purposes:
-        
+
             1. when set on an SSL client, it is sent to the server during the
                handshake (if Server Name Indication is supported)
             2. it is used to check against the identifying name provided in the
@@ -1193,7 +1216,7 @@ class SSL(object):
                SubjectAltName (type DNS name), or the CommonName entry in the
                peer's certificate, the peer is considered unauthenticated
                (potential imposter), and the SSL connection is aborted.
- 
+
         .. note:: Verification of the hostname is only done if
             :const:`SSLDomain.VERIFY_PEER_NAME` is set using
             :meth:`SSLDomain.set_peer_authentication`.
@@ -1214,7 +1237,7 @@ class SSLSessionDetails(object):
     def get_session_id(self):
         """
         Get the unique identifier for this SSL session
-        
+
         :return: Session identifier
         :rtype: ``str``
         """
